==> ansible_11.2.0+dfsg.orig.tar.xz: ansible-11.2.0/ansible_collections/cisco/dnac/plugins/modules/file_namespaces_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: file_namespaces_info
short_description: Information module for File Namespaces Info
description:
- This module represents an alias of the module file_namespaces_v1_info
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for File GetListOfAvailableNamespacesV1
  description: Complete reference of the GetListOfAvailableNamespacesV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-list-of-available-namespaces
notes:
  - SDK Method used are
    file.File.get_list_of_available_namespaces_v1,

  - Paths used are
    get /dna/intent/api/v1/file/namespace,
  - It should be noted that this module is an alias of file_namespaces_v1_info

"""

EXAMPLES = r"""
- name: Get all File Namespaces Info
  cisco.dnac.file_namespaces_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        "string"
      ],
      "version": "string"
    }
"""

==> ansible_12.0.0~b1+dfsg.orig.tar.xz: ansible-12.0.0b1/ansible_collections/cisco/dnac/plugins/modules/file_namespaces_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: file_namespaces_info
short_description: Information module for File Namespaces
description:
  - Get all File Namespaces.
  - Returns list of available namespaces.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for File GetListOfAvailableNamespaces
    description: Complete reference of the GetListOfAvailableNamespaces
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-list-of-available-namespaces
notes:
  - SDK Method used are
    file.File.get_list_of_available_namespaces,
  - Paths used are
    get /dna/intent/api/v1/file/namespace,
"""

EXAMPLES = r"""
---
- name: Get all File Namespaces
  cisco.dnac.file_namespaces_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        "string"
      ],
      "version": "string"
    }
"""
